@@ -11,7 +11,7 @@
 
 This project provides a CDK construct to create an S3 Bucket with some security pre-sets. It uses usual [s3.BucketProps](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-s3.BucketProps.html) and overrides these key-value pairs:
 
-```python
+```typescript
 {
   blockPublicAccess: s3.BlockPublicAccess.BLOCK_ALL,
   enforceSSL: true,
@@ -65,7 +65,7 @@ npm install @pepperize/cdk-private-bucket
 
 See [API.md](https://github.com/pepperize/cdk-private-bucket/blob/main/API.md).
 
-```python
+```typescript
 import { PrivateBucket } from "@pepperize/cdk-private-bucket";
 
 const bucket = new PrivateBucket(this, "PrivateBucket", {});
